# flake8: noqa

# import apis into api package
from openproject_api_client.api.actions_capabilities_api import ActionsCapabilitiesApi
from openproject_api_client.api.activities_api import ActivitiesApi
from openproject_api_client.api.attachments_api import AttachmentsApi
from openproject_api_client.api.budgets_api import BudgetsApi
from openproject_api_client.api.categories_api import CategoriesApi
from openproject_api_client.api.collections_api import CollectionsApi
from openproject_api_client.api.configuration_api import ConfigurationApi
from openproject_api_client.api.custom_options_api import CustomOptionsApi
from openproject_api_client.api.custom_actions_api import CustomActionsApi
from openproject_api_client.api.documents_api import DocumentsApi
from openproject_api_client.api.emoji_reactions_api import EmojiReactionsApi
from openproject_api_client.api.favorites_api import FavoritesApi
from openproject_api_client.api.file_links_api import FileLinksApi
from openproject_api_client.api.file_links_api import FileLinksApi
from openproject_api_client.api.forms_api import FormsApi
from openproject_api_client.api.grids_api import GridsApi
from openproject_api_client.api.groups_api import GroupsApi
from openproject_api_client.api.help_texts_api import HelpTextsApi
from openproject_api_client.api.meetings_api import MeetingsApi
from openproject_api_client.api.memberships_api import MembershipsApi
from openproject_api_client.api.news_api import NewsApi
from openproject_api_client.api.notifications_api import NotificationsApi
from openproject_api_client.api.o_auth2_api import OAuth2Api
from openproject_api_client.api.posts_api import PostsApi
from openproject_api_client.api.previewing_api import PreviewingApi
from openproject_api_client.api.principals_api import PrincipalsApi
from openproject_api_client.api.priorities_api import PrioritiesApi
from openproject_api_client.api.project_phase_definitions_api import ProjectPhaseDefinitionsApi
from openproject_api_client.api.project_phases_api import ProjectPhasesApi
from openproject_api_client.api.projects_api import ProjectsApi
from openproject_api_client.api.queries_api import QueriesApi
from openproject_api_client.api.query_columns_api import QueryColumnsApi
from openproject_api_client.api.query_filter_instance_schema_api import QueryFilterInstanceSchemaApi
from openproject_api_client.api.query_filters_api import QueryFiltersApi
from openproject_api_client.api.query_operators_api import QueryOperatorsApi
from openproject_api_client.api.query_sort_bys_api import QuerySortBysApi
from openproject_api_client.api.relations_api import RelationsApi
from openproject_api_client.api.reminders_api import RemindersApi
from openproject_api_client.api.revisions_api import RevisionsApi
from openproject_api_client.api.roles_api import RolesApi
from openproject_api_client.api.root_api import RootApi
from openproject_api_client.api.schemas_api import SchemasApi
from openproject_api_client.api.statuses_api import StatusesApi
from openproject_api_client.api.time_entries_api import TimeEntriesApi
from openproject_api_client.api.time_entries_api import TimeEntriesApi
from openproject_api_client.api.time_entry_activities_api import TimeEntryActivitiesApi
from openproject_api_client.api.types_api import TypesApi
from openproject_api_client.api.user_preferences_api import UserPreferencesApi
from openproject_api_client.api.users_api import UsersApi
from openproject_api_client.api.values_property_api import ValuesPropertyApi
from openproject_api_client.api.versions_api import VersionsApi
from openproject_api_client.api.views_api import ViewsApi
from openproject_api_client.api.wiki_pages_api import WikiPagesApi
from openproject_api_client.api.work_packages_api import WorkPackagesApi
from openproject_api_client.api.work_packages_api import WorkPackagesApi
from openproject_api_client.api.work_schedule_api import WorkScheduleApi
from openproject_api_client.api.default_api import DefaultApi

